
/**
 * Clase que representa un sistema de alarma
 */
public class SistemaAlarma
{
    // atributos privados
    private ListadoMensajes lista;

    /**
     * Constructor que crea la lista de mensajes vaca
     */
    public SistemaAlarma(String nombre)
    {
        lista=new ListadoMensajes();
        // el nombre se ignora, pues no es necesario almacenarlo
    }

    /**
     * Procesa los sensores de alarma que se pasan en el array s,
     * recorriendo sus elementos. Para cada uno llama a lee()
     * y luego a hayAlarma(). Si hay alarma inserta en la lista un mensaje
     * de tipo 1, y cuyo texto es el devuelto por estado()
     * Retorna el numero de alarmas detectadas
     */
    public int procesaSensores(Sensor[] s)
    {
        ...
    }
    
    /**
     * Retorna el numero de mensajes del tipo tipoMensaje que existen en la lista
     */
    public int numMensajesTipo(int tipoMensaje) {
        int contador=0;
        lista.reinicia();
        while (! lista.finalSecuencia()) {
            Mensaje m=lista.mensajeActual();
            if (m.tipo()==tipoMensaje) {
                contador++;
            }
            lista.avanza();
        }
        return contador;
    }
    
    /**
     * Busca y retorna el texto del primer mensaje anterior 
     * a la hora y minutos indicados
     */
    public String buscaMensajeAnteriorA(int hora, int  minuto) {
        boolean encontrado=false;
        Mensaje m=new Mensaje(0,""); // para inicializar m
        lista.reinicia();
        while (! lista.finalSecuencia() && ! encontrado) {
            m=lista.mensajeActual();
            if (m.hora()*60+m.minuto()<hora*60+minuto) {
                encontrado=true;
            } 
            if (!encontrado) {
                lista.avanza();
            }
        }
        if (encontrado) {
           return m.texto();
        } else {
            return null;
        }
    }
    
    /**
     * Crea una nueva secuencia de mensajes del tipo ListadoMensajes, 
     * anade a ella los mensajes anteriores a la hora y minutos 
     * indicados y cuyo tipo coincide con tipoMensaje, y retorna la
     * nueva secuencia
     */
    public ListadoMensajes mensajesAnterioresDeTipo
        (int hora, int minuto, int tipoMensaje)
   {
       ListadoMensajes nuevo=new ListadoMensajes();
        lista.reinicia();
        while (! lista.finalSecuencia()) {
            Mensaje m=lista.mensajeActual();
            if (m.tipo()==tipoMensaje) {
                if (m.hora()*60+m.minuto()<hora*60+minuto) {
                    nuevo.anade(m);
                } 
            }
            lista.avanza();
        }
        return nuevo;
   } 
   
   /**
    * Muestra en pantalla cada uno de los mensajes que contiene,
    * la lista, uno por lnea, con la hora (hh), los minutos (mm), 
    * el tipo (tt) y el texto del mensaje (xxxx), con el siguiente formato:
    * hh:mm - tt = xxxx 
    */
   public void muestra() 
   {
      ...
   }
}
